==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/viking2/dialogs_cs.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Tahle loď tu asi leží už dlouho.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It’s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Určitě. Je to jeden z raných drakarů. Podle tvaru hlavy, počtu závitů a barvy vody soudím, že patřil dědečkovi Erika Rudého.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("Nebo tchánovi Olafa Udatného.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("Nebo možná prastrýci Leifa Smělého.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("Není vyloučeno, že neteři Harolda Velkého.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("Je možné, že i tetě Snorra Statečného.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("Nedá se vyloučit ani Thorson Tvrdý.")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it’s never too late to start a new life!")
dialogStr("Vždycky jsem si myslel, že jsem byl rybářský člun Erika Nepřipraveného... Ale dnes jsem se konečně dozvěděl pravdu. Nu což, nikdy není pozdě začít nový život!")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Podívej, ten chudáček pejsek.")


dialogId("dr-m-nedycha", "font_small", "Doesn't he seem to be breathing kind of strangely?")
dialogStr("Nedýchá nějak nemocně?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he's doing rather well.")
dialogStr("Na psa pod vodou dýchá celkem slušně.")


dialogId("dr-v-nato", "font_big", "He doesn't look all that bad considering that he's been here for a few centuries.")
dialogStr("Na to, že tu musí být několik století, je celkem čilý.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("Ztichni!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("Buď už zticha!")


dialogId("dr-8-nenechas", "font_viking8", "So, you’re not going to shut up, are you?")
dialogStr("Tak ty toho nenecháš?!")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Ááááá...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("Chééééchechech... chéééchecheche... chechechechéééchéé...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("Už je po všem?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("Je tady bezpečno?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("Už skončil boj?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("Už jsou nepřátelé pryč?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("Ještě se bojuje?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("Už jsme ve Valhale, náčelníku?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("Už budeme ve Valhale?")


dialogId("dr-1-aztambudem", "font_viking1", "I’ll let you know once we get there.")
dialogStr("Až tam budem, tak ti řeknu.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("Náčelníku, můžu si odskočit?")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Počkej, až budeme ve Valhale.")


dialogId("dr-2-netrva", "font_viking2", "Isn’t this journey to Valhalla taking a bit too long?")
dialogStr("Netrvá ta cesta do Valhaly už nějak dlouho?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Trpělivost, to je odznak bojovníka.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("Určitě se takhle dostaneme do Valhaly?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("Bojovník musí svému veliteli důvěřovat!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I’m in charge of a ship full of cowards.")
dialogStr("Ach jo, velím lodi plné zbabělců.")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("Proč zrovna já musím mít loď plnou chechtajících se kreténů.")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I’ll go drown myself.")
dialogStr("Chechtající se kreténi, slintající pes. Já se snad utopím.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Správný viking má mít vous.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("C-c-copy jsou teď v m-módě.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("Co je tohle za módu. Copy. To snad ne.")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("M-m-magazín Vikingská m-m-móda d-doporučuje k tmavé helmě a m-modrému štítu právě světlý c-c-cop.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don’t agree with such a fad.")
dialogStr("S takovou módou zásadně nesouhlasím.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("Raději kdyby ses držel vikingských tradic.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I’m c-c-cool!")
dialogStr("N-n-náhodou, jsem m-moderní!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("Už v-v-velký Erik měl c-c-cop!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Nesmysl. Měl vousy.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("Ale c-c-cop měl t-t-taky.")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that’s final.")
dialogStr("Neměl. A dost řečí.")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("M-m-myslíš, že by mi v-v-vous slušel l-lépe?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Samozřejmě.")


dialogId("dr-4-budu", "font_viking4", "I’ll th-th-think it o-over.")
dialogStr("B-b-budu o tom u-uvažovat.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("N-ne, c-c-copy jsou určitě l-l-lepší.")


dialogId("dr-3-mladez", "font_viking3", "Today’s youth - absolutely unbelievable.")
dialogStr("Ta dnešní mládež je příšerná.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It’s unheard of.")
dialogStr("Chlap a copy. Kdo to kdy slyšel!?")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Dnes si ti mladí dovolí snad cokoliv.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("Stejně mi to sluší...")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/viking2/dialogs_cs.lua <==

dialogId("dr1-m-dlouho", "font_small", "This ship must have sunk long time ago.")
dialogStr("Tahle loď tu asi leží už dlouho.")


dialogId("dr1-v-urcite", "font_big", "Definitely. It’s one of the earliest drakkars. Judging by the shape of the head, number of spirals and color of the water I think it belonged to the grandfather of Eric the Red.")
dialogStr("Určitě. Je to jeden z raných drakarů. Podle tvaru hlavy, počtu závitů a barvy vody soudím, že patřil dědečkovi Erika Rudého.")


dialogId("dr1-v-olaf", "font_big", "Or to the father-in-law of Olaf the Brave.")
dialogStr("Nebo tchánovi Olafa Udatného.")


dialogId("dr1-v-leif", "font_big", "Or maybe to the great-uncle of Leif the Skillful.")
dialogStr("Nebo možná prastrýci Leifa Smělého.")


dialogId("dr1-v-harold", "font_big", "It could also belong to the niece of Harold the Great.")
dialogStr("Není vyloučeno, že neteři Harolda Velkého.")


dialogId("dr1-v-snorr", "font_big", "Or possibly to the aunt of Snorr the Courageous.")
dialogStr("Je možné, že i tetě Snorra Statečného.")


dialogId("dr1-v-thorson", "font_big", "It is even possible it belonged to Thorson the Hard.")
dialogStr("Nedá se vyloučit ani Thorson Tvrdý.")


dialogId("dr1-x-erik", "font_lightgrey", "I always thought I was the fishing boat of Eric the Unready... But today I learned the truth. Yes, it’s never too late to start a new life!")
dialogStr("Vždycky jsem si myslel, že jsem byl rybářský člun Erika Nepřipraveného... Ale dnes jsem se konečně dozvěděl pravdu. Nu což, nikdy není pozdě začít nový život!")


dialogId("dr-m-podivej", "font_small", "Look at that poor dog.")
dialogStr("Podívej, ten chudáček pejsek.")


dialogId("dr-m-nedycha", "font_small", "Doesn’t he seem to be breathing kind of strangely?")
dialogStr("Nedýchá nějak nemocně?")


dialogId("dr-v-napsa", "font_big", "For a dog under water I think he’s doing rather well.")
dialogStr("Na psa pod vodou dýchá celkem slušně.")


dialogId("dr-v-nato", "font_big", "He doesn’t look all that bad considering that he’s been here for a few centuries.")
dialogStr("Na to, že tu musí být několik století, je celkem čilý.")


dialogId("dr-8-ztichni1", "font_viking8", "Shut up!")
dialogStr("Ztichni!")


dialogId("dr-8-ztichni2", "font_viking8", "Will you shut up already!")
dialogStr("Buď už zticha!")


dialogId("dr-8-nenechas", "font_viking8", "So, you’re not going to shut up, are you?")
dialogStr("Tak ty toho nenecháš?!")


dialogId("dr-8-aaa", "font_viking8", "Aaaaargh...")
dialogStr("Ááááá...")


dialogId("dr-6-checheche", "font_viking6", "He-he-he-he-he... Eh-eh-eh-eh...")
dialogStr("Chééééchechech... chéééchecheche... chechechechéééchéé...")


dialogId("dr-5-srab1", "font_viking5", "Is it over?")
dialogStr("Už je po všem?")


dialogId("dr-5-srab2", "font_viking5", "Are we safe now?")
dialogStr("Je tady bezpečno?")


dialogId("dr-5-srab3", "font_viking5", "Is the fight over?")
dialogStr("Už skončil boj?")


dialogId("dr-5-srab4", "font_viking5", "Is the enemy finally gone?")
dialogStr("Už jsou nepřátelé pryč?")


dialogId("dr-5-srab5", "font_viking5", "Are we still fighting?")
dialogStr("Ještě se bojuje?")


dialogId("dr-2-uzbudeme1", "font_viking2", "Are we in Valhalla yet, chief?")
dialogStr("Už jsme ve Valhale, náčelníku?")


dialogId("dr-2-uzbudeme2", "font_viking2", "When are we going to get to Valhalla?")
dialogStr("Už budeme ve Valhale?")


dialogId("dr-1-aztambudem", "font_viking1", "I’ll let you know once we get there.")
dialogStr("Až tam budem, tak ti řeknu.")


dialogId("dr-2-odskocit", "font_viking2", "Can I go relieve myself, sir?")
dialogStr("Náčelníku, můžu si odskočit?")


dialogId("dr-1-pockej", "font_viking1", "Wait till we get to Valhalla.")
dialogStr("Počkej, až budeme ve Valhale.")


dialogId("dr-2-netrva", "font_viking2", "Isn’t this journey to Valhalla taking a bit too long?")
dialogStr("Netrvá ta cesta do Valhaly už nějak dlouho?")


dialogId("dr-1-trpelivost", "font_viking1", "Patience is the sign of a true warrior.")
dialogStr("Trpělivost, to je odznak bojovníka.")


dialogId("dr-2-urcite", "font_viking2", "Are you sure this is how to get to Valhalla?")
dialogStr("Určitě se takhle dostaneme do Valhaly?")


dialogId("dr-1-bojovnik", "font_viking1", "A warrior has to trust his commander!")
dialogStr("Bojovník musí svému veliteli důvěřovat!")


dialogId("dr-1-achjo", "font_viking1", "Ahhh, I’m in charge of a ship full of cowards.")
dialogStr("Ach jo, velím lodi plné zbabělců.")


dialogId("dr-1-procja", "font_viking1", "Why did I have to get a ship full of laughing buffoons?")
dialogStr("Proč zrovna já musím mít loď plnou chechtajících se kreténů.")


dialogId("dr-1-chechtajici", "font_viking1", "Laughing buffoons, a slobbering dog. I think I’ll go drown myself.")
dialogStr("Chechtající se kreténi, slintající pes. Já se snad utopím.")


dialogId("dr-3-spravny", "font_viking3", "Real Vikings have beards.")
dialogStr("Správný viking má mít vous.")


dialogId("dr-4-copy", "font_viking4", "B-b-braids are in n-nowadays.")
dialogStr("C-c-copy jsou teď v m-módě.")


dialogId("dr-3-cojeto", "font_viking3", "What kind of fad is that? Braids? For crying out loud.")
dialogStr("Co je tohle za módu. Copy. To snad ne.")


dialogId("dr-4-magazin", "font_viking4", "V-v-viking Fashion M-m-monthly r-recommends a blonde braid to complement a d-d-dark helmet and b-blue shield.")
dialogStr("M-m-magazín Vikingská m-m-móda d-doporučuje k tmavé helmě a m-modrému štítu právě světlý c-c-cop.")


dialogId("dr-3-stakovou", "font_viking3", "I simply don’t agree with such a fad.")
dialogStr("S takovou módou zásadně nesouhlasím.")


dialogId("dr-3-radeji", "font_viking3", "You should stick to the Viking traditions instead.")
dialogStr("Raději kdyby ses držel vikingských tradic.")


dialogId("dr-4-moderni", "font_viking4", "B-b-but I’m c-c-cool!")
dialogStr("N-n-náhodou, jsem m-moderní!")


dialogId("dr-4-erik", "font_viking4", "Even Erik the G-g-great Eric had a b-b-braid!")
dialogStr("Už v-v-velký Erik měl c-c-cop!")


dialogId("dr-3-nesmysl", "font_viking3", "Nonsense. He had a beard.")
dialogStr("Nesmysl. Měl vousy.")


dialogId("dr-4-taky", "font_viking4", "But h-he also h-had a b-b-braid.")
dialogStr("Ale c-c-cop měl t-t-taky.")


dialogId("dr-3-nemel", "font_viking3", "He did not. And that’s final.")
dialogStr("Neměl. A dost řečí.")


dialogId("dr-4-myslis", "font_viking4", "D-d-do you think that a b-b-beard would suit me b-b-better?")
dialogStr("M-m-myslíš, že by mi v-v-vous slušel l-lépe?")


dialogId("dr-3-samozrejme", "font_viking3", "Definitely.")
dialogStr("Samozřejmě.")


dialogId("dr-4-budu", "font_viking4", "I’ll th-th-think it o-over.")
dialogStr("B-b-budu o tom u-uvažovat.")


dialogId("dr-4-hmmm", "font_viking4", "Hmmm... Ehmmm... Hahmmm...")
dialogStr("Hmmm... Ehmmm... Hahmmm...")


dialogId("dr-4-ne", "font_viking4", "N-no, b-b-braids are d-definitely b-b-better.")
dialogStr("N-ne, c-c-copy jsou určitě l-l-lepší.")


dialogId("dr-3-mladez", "font_viking3", "Today’s youth - absolutely unbelievable.")
dialogStr("Ta dnešní mládež je příšerná.")


dialogId("dr-3-chlap", "font_viking3", "A warrior with braids. It’s unheard of.")
dialogStr("Chlap a copy. Kdo to kdy slyšel!?")


dialogId("dr-3-mladi", "font_viking3", "You youngsters just think you can get away with anything today.")
dialogStr("Dnes si ti mladí dovolí snad cokoliv.")


dialogId("dr-4-stejne", "font_viking4", "Well, I still look cool.")
dialogStr("Stejně mi to sluší...")
